@@ -3,13 +3,16 @@ package org.ohdsi.sql;
 public class TestSqlRender {
 
 	public static void main(String[] args) {
+//		Pattern pattern = Pattern.compile("^((?!FROM).)*$");
+//		System.out.println(pattern.matcher("SELECT * blaat b;").matches());
+		
 //		String sql = "SELECT * FROM table {@a = true} ?  {WHERE name = '@name'};";
 //		sql = SqlRender.renderSql(sql, new String[]{"name", "a"}, new String[]{"NA\\joe", "true"});
 //		System.out.println(sql);	
 		String path = "inst/csv/replacementPatterns.csv";
-		String sourceSql = "SELECT CONCAT(a,\" , \",c,d,e) FROM x";
+		String sourceSql = "SELECT TOP 10 * FROM my_table WHERE a = b;";
 		String sql;
-		sql = SqlTranslate.translateSqlWithPath(sourceSql, "oracle", null, null, path);
+		sql = SqlTranslate.translateSqlWithPath(sourceSql, "postgresql", null, null, path);
 		System.out.println(sql);		
 //		
 //		sql = SqlTranslate.translateSqlWithPath(sourceSql, "oracle", null, null, path);
